package com.qima.gift.appcommon.account.service;

import com.qima.gift.appcommon.account.AccountConst;
import com.qima.gift.appcommon.account.AccountConst.AccountAuthTypeEnum;
import com.qima.gift.appcommon.account.authc.IAccountAuthc;
import com.qima.gift.appcommon.account.bean.AccountAuth;
import com.qima.gift.appcommon.account.bean.AccountInfoBO;
import com.qima.gift.appcommon.account.bean.AccountInfo;
import com.qima.gift.common.CommonConst;
import com.qima.gift.common.Result;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/4 17:48
 */
public interface IAccountService {

    /**
     * 做账户认证
     * @param t 类型
     * @param principal 凭证
     * @param credentials 信息
     * @return 是否符合
     */
    Result<String> doAuth(AccountAuthTypeEnum t, String principal, String credentials);

    /**
     * 注册一个认证器
     * @param auth 认证器
     */
    void registIAccountAuth(IAccountAuthc auth);

    /**
     * 根据账户ID查询
     * @param accountId
     * @return
     */
    AccountInfoBO findAccountById(String accountId);

    /**
     * 查询凭证是否存在
     * @param t 类型
     * @param principal 凭证
     * @return 对象
     */
    AccountInfoBO findAccountByPrincipal(AccountAuthTypeEnum t, String principal);

    /**
     * 创建账户
     * @param info 账户
     * @return 账户
     */
    AccountInfoBO createAccount(AccountInfo info);

    /**
     * 给创建好的账户添加凭证
     * @param accountId 账户ID
     * @param e 要添加的类型
     * @param p 要添加的标识
     * @param c 要添加的凭证
     * @return 完整的BO
     */
    AccountInfoBO saveAccountAuth(String accountId, AccountAuthTypeEnum e, String p, String c);

    /**
     * 创建账户并创建凭证
     * @param info 账户
     * @param auth 凭证
     * @return 账户
     */
    AccountInfoBO createAccount(AccountInfo info, AccountAuth auth);

    /**
     * 根据凭证创建账户
     * @param name
     * @param e
     * @param p
     * @param c
     * @return
     */
    AccountInfoBO createAccount(String name, AccountConst.AccountAuthTypeEnum e, String p, String c);

    /**
     * 调整状态
     * @param accountId
     * @param e
     * @return
     */
    AccountInfoBO doAccountState(String accountId, CommonConst.StateEnum e);

    /**
     * 根据电话，完善账户信息
     * @param accountId
     * @param name
     * @param phone
     * @return
     */
    AccountInfoBO doAccountInfoFill(String accountId, String name, String phone);

}
