package com.qima.gift.appcommon.security.service;

import cn.dev33.satoken.stp.StpUtil;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.qima.gift.appcommon.security.base.ISecurityListener;
import com.qima.gift.appcommon.security.satoken.LoginDataDTO;
import com.qima.gift.common.AppException;
import com.qima.gift.common.utils.ObjectUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.annotation.Scope;
import org.springframework.context.annotation.ScopedProxyMode;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/5 15:40
 */
@Service
@Slf4j
@Scope(proxyMode = ScopedProxyMode.NO)
public class SecurityServiceImpl implements ISecurityService{

    private Map<String, LoginDataDTO> attrMap = Maps.newConcurrentMap();

    private List<ISecurityListener> listeners = Lists.newArrayList();

    @Override
    public LoginDataDTO logIn(String token, String accountId) {
        if(ObjectUtils.isAnyNull(token)) {
            throw new AppException("未登录");
        } else {
            LoginDataDTO dto = attrMap.computeIfAbsent(token, k->LoginDataDTO.build(accountId, (String)token));
            doLogin("登录", dto);
            return dto;
        }
    }

    @Override
    public LoginDataDTO logOut() {
        String token = StpUtil.getTokenValue();
        return logOut(token);
    }

    @Override
    public LoginDataDTO logOut(String token) {
        if(ObjectUtils.isAnyNull(token)) {
            throw new AppException("未登录");
        } else {
            LoginDataDTO dto = attrMap.remove(token);
            doLogout("退出", dto);
            return dto;
        }
    }

    @Override
    public LoginDataDTO getLoginData() {
        String token = StpUtil.getTokenValue();
        return getLoginDataByToken(token);
    }

    protected LoginDataDTO getLoginDataByToken(String token) {
        if(ObjectUtils.isAnyNull(token)) {
            throw new AppException("未登录");
        } else {
            LoginDataDTO dto = attrMap.get(token);
            doLoad("获取数据",dto);
            return dto;
        }
    }

    @Override
    public void registSecurityListener(ISecurityListener listener) {
        if(listener == null) {
            throw new AppException("安全监听不能为空");
        }
        if(listeners.contains(listener)) {
            throw new AppException("安全监听不能重复");
        }
        int order = listener.getOrder();
        if(listeners.isEmpty()) {
            listeners.add(listener);
        } else {
            int insert = 0;
            for(int i=(listeners.size()-1);i>=0;i--) {
                int o = listeners.get(i).getOrder();
                if(o <= order) {
                    insert = i+1;
                    break;
                }
            }
            listeners.add(insert,listener);
        }
    }

    protected void doLoad(String msg, LoginDataDTO dto) {
        for(ISecurityListener l:listeners) {
            l.onLoad(dto);
        }
        log.info("获取用户信息完成,"+msg);
    }

    protected void doLogin(String msg, LoginDataDTO dto) {
        for(ISecurityListener l:listeners) {
            l.onLogin(dto);
        }
        log.info("用户登录完成,"+msg);
    }

    protected void doLogout(String msg, LoginDataDTO dto) {
        for(ISecurityListener l:listeners) {
            l.onLogout(dto);
        }
        log.info("用户登出完成,"+msg);
    }
}
