package com.qima.gift.appcommon.space.controller;

import cn.hutool.core.io.IoUtil;
import com.qima.gift.appcommon.space.base.Base64FileSource;
import com.qima.gift.appcommon.space.base.IFileSource;
import com.qima.gift.appcommon.space.base.MultipartFileSource;
import com.qima.gift.appcommon.space.bean.SpaceFile;
import com.qima.gift.appcommon.space.bean.SpaceFileDTO;
import com.qima.gift.appcommon.space.service.ISpaceService;
import com.qima.gift.appcommon.space.utils.SpaceUtils;
import com.qima.gift.common.AppException;
import com.qima.gift.common.Result;
import com.qima.gift.common.utils.CollectionUtils;
import com.qima.gift.common.utils.JsonUtils;
import com.qima.gift.common.utils.ObjectUtils;
import io.swagger.v3.oas.annotations.Operation;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.List;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/9 14:49
 */
@RestController
@Slf4j
public class SpaceController {

    @Autowired
    private ISpaceService spaceService;

    @PostMapping("/files/uploadbase64")
    @Operation( summary = "上传图片-多个", description = "scope：'formal'表示正式，不传递表示临时（默认）；内容格式:[{\"fileName\":\"test.img\",\"contentType\":\"可以不传\",\"content\":\"data:image/png;base64,/9j/4AAQSkZJ....等编码信息\"}]")
    public Result<List<SpaceFileDTO>> uploadFileByBase64(@RequestParam String scope, @RequestBody String json) {
        List<Base64FileSource> sources = JsonUtils.toObjectList(json, Base64FileSource.class);
        String des = "formal".equals(scope)?"正式文件":"临时文件";
        if(CollectionUtils.isNotEmpty(sources)) {
            List<SpaceFile> f = null;
            if("formal".equals(scope)) {
                f = spaceService.createSpaceFile(sources);
            } else {
                f = spaceService.createSpaceFileOfTmp(sources);
            }
            if(ObjectUtils.isNotNull(f)) {
                return Result.ok("上传"+des+"成功", CollectionUtils.convert(f,SpaceUtils::convert));
            } else {
                return Result.fail("上传"+des+"失败");
            }
        } else {
            return Result.fail("上传"+des+"失败");
        }
    }

    @PostMapping("/files/upload")
    @Operation( summary = "上传文件-多个", description = "scope：'formal'表示正式，不传递表示临时（默认）；内容格式：标准文件流")
    public Result<List<SpaceFileDTO>> uploadFile(@RequestParam(required = false) String scope, @RequestPart List<MultipartFile> files) {
        String des = "formal".equals(scope)?"正式文件":"临时文件";
        if(CollectionUtils.isNotEmpty(files)) {
            List<IFileSource> fs = CollectionUtils.convert(files, MultipartFileSource::new);
            List<SpaceFile> savedFiles = null;
            if("formal".equals(scope)) {
                savedFiles = spaceService.createSpaceFile(fs);
            } else {
                savedFiles = spaceService.createSpaceFileOfTmp(fs);
            }
            if(ObjectUtils.isNotNull(savedFiles)) {
                return Result.ok("上传"+des+"成功", CollectionUtils.convert(savedFiles,SpaceUtils::convert));
            } else {
                return Result.fail("上传"+des+"失败");
            }
        } else {
            return Result.fail("上传"+des+"失败");
        }
    }

    @GetMapping("/files/{fileId}/show")
    @Operation(summary = "展示图片")
    public void showImage(@PathVariable String fileId, HttpServletRequest request, HttpServletResponse response) {
        IFileSource s = spaceService.findSpaceFileAsStream(fileId);
        if( ObjectUtils.isAnyNull(s) ) {
            throw new AppException("找不到文件");
        } else {
            InputStream is = null;
            try{
                response.setContentType(s.getContentType());
                is = s.getInputStream();
                OutputStream os = response.getOutputStream();
                IoUtil.copy(is,os);
            } catch (Exception e) {
                response.setContentType("application/json");
                throw new AppException("展示图片失败",e);
            } finally {
                IoUtil.close(is);
            }
        }
    }

    @GetMapping("/files/{fileId}/download")
    @Operation(summary = "下载文件")
    public void downloadFile(@PathVariable String fileId, HttpServletRequest request, HttpServletResponse response) {
        IFileSource s = spaceService.findSpaceFileAsStream(fileId);
        if( ObjectUtils.isAnyNull(s) ) {
            throw new AppException("找不到文件");
        } else {
            InputStream is = null;
            try{
                response.setContentType(s.getContentType());
                is = s.getInputStream();
                OutputStream os = response.getOutputStream();
                IoUtil.copy(is,os);
            } catch (Exception e) {
                response.setContentType("application/json");
                throw new AppException("下载文件失败",e);
            } finally {
                IoUtil.close(is);
            }
        }
    }

}
