package com.qima.gift.appcommon.space.service;

import cn.dev33.satoken.stp.StpUtil;
import com.google.common.collect.Lists;
import com.qima.gift.appcommon.space.base.IFileSource;
import com.qima.gift.appcommon.space.base.SpaceFileReadFileSource;
import com.qima.gift.appcommon.space.bean.SpaceFile;
import com.qima.gift.appcommon.space.dao.SpaceFileMapper;
import com.qima.gift.appcommon.space.utils.SpaceUtils;
import com.qima.gift.common.AppException;
import com.qima.gift.common.CommonConst;
import com.qima.gift.common.utils.CollectionUtils;
import com.qima.gift.common.utils.ObjectUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.context.annotation.ScopedProxyMode;
import org.springframework.core.io.InputStreamSource;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/9 11:26
 */
@Service
@Slf4j
@Scope(proxyMode = ScopedProxyMode.NO)
public class SpaceServiceImpl implements ISpaceService{

    @Autowired
    private SpaceFileMapper spaceFileMapper;

    @Autowired
    private StorageService storageService;

    @Override
    public List<SpaceFile> createSpaceFileOfTmp(List<? extends IFileSource> sources) {
        if(CollectionUtils.isEmpty(sources)) { return null; }
        List<SpaceFile> r = Lists.newArrayList();
        for(IFileSource source : sources) {
            SpaceFile f = createSpaceFileOfState(source,CommonConst.StateEnum.Unkown);
            r.add(f);
        }
        return r;
    }

    @Override
    public List<SpaceFile> createSpaceFile(List<? extends IFileSource> sources) {
        if(CollectionUtils.isEmpty(sources)) { return null; }
        List<SpaceFile> r = Lists.newArrayList();
        for(IFileSource source : sources) {
            SpaceFile f = createSpaceFileOfState(source,CommonConst.StateEnum.Enable);
            r.add(f);
        }
        return r;
    }

    protected SpaceFile createSpaceFileOfState(IFileSource source, CommonConst.StateEnum state) {
        if(ObjectUtils.isAnyNull(source)) {
            throw new AppException("保存的文件不能为空");
        }
        SpaceFile f = new SpaceFile();
        SpaceUtils.fillBeanBeforeInsert(f);
        f.setState(state.getKey());
        f.setOwnerId((String)StpUtil.getLoginId());// 登陆者
        f.setOwnerType("unkown");
        f.setResId("");
        f.setResType("unkown");
        f.setName(source.getFileName());
        f.setType(source.getContentType());
        storageService.doStorage(f, source);
        spaceFileMapper.insert(f);
        return f;
    }

    @Override
    public List<SpaceFile> doFormal(List<String> fileIds) {
        if(CollectionUtils.isNotEmpty(fileIds)) {
            List<SpaceFile> r = Lists.newArrayList();
            for(String fileId:fileIds) {
                if(StringUtils.isBlank(fileId)) {return null;}
                SpaceFile f = spaceFileMapper.selectByPrimaryKey(fileId);
                if(ObjectUtils.isNotNull(f)) {
                    r.add(f);
                    if(!CommonConst.StateEnum.Enable.getKey().equals(f.getState())) {
                        f.setState(CommonConst.StateEnum.Enable.getKey());
                        SpaceUtils.fillBeanBeforeUpdate(null,f);
                        spaceFileMapper.updateByPrimaryKey(f);
                    }
                } else {
                    throw new AppException("文件不存在").setM(fileId);
                }
            }
            return r;
        }
        return null;
    }

    @Override
    public Boolean deleteSpaceFile(String fileId) {
        SpaceFile f = spaceFileMapper.selectByPrimaryKey(fileId);
        if(ObjectUtils.isNotNull(f)) {
            storageService.deleteStorage(f);
            spaceFileMapper.deleteByPrimaryKey(fileId);
        } else {
            log.warn("文件已经不存在，file="+fileId);
        }
        return Boolean.TRUE;
    }

    @Override
    public SpaceFile findSpaceFile(String fileId) {
        return spaceFileMapper.selectByPrimaryKey(fileId);
    }

    @Override
    public IFileSource findSpaceFileAsStream(String fileId) {
        SpaceFile f = spaceFileMapper.selectByPrimaryKey(fileId);
        if(ObjectUtils.isAnyNull(f)) {
            throw new AppException("文件不存在").setM(fileId);
        } else {
            return storageService.readStorage(f);
        }
    }
}
