package com.qima.gift.appcommon.wechat.authc;

import com.qima.gift.appcommon.account.AccountConst;
import com.qima.gift.appcommon.account.authc.Authentication;
import com.qima.gift.appcommon.account.authc.IAccountAuthc;
import com.qima.gift.appcommon.account.authc.IAuthEncode;
import com.qima.gift.appcommon.account.bean.AccountInfoBO;
import com.qima.gift.appcommon.account.service.IAccountService;
import com.qima.gift.appcommon.wechat.service.IWeChatService;
import com.qima.gift.common.utils.ObjectUtils;
import jakarta.annotation.PostConstruct;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.context.annotation.ScopedProxyMode;
import org.springframework.stereotype.Component;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/6 17:40
 */
@Component
@Scope(proxyMode = ScopedProxyMode.NO)
public class WeChatAccountAuthc implements IAccountAuthc {

    public static final AccountConst.AccountAuthTypeEnum TYPE = AccountConst.AccountAuthTypeEnum.WeChat;

    @Autowired
    private IAccountService accountService;

    @Autowired
    private IWeChatService weChatService;

    @PostConstruct
    protected void init() {
        accountService.registIAccountAuth(this);
    }

    @Override
    public Authentication doAuth(Authentication custom, IAuthEncode encode) {
        // 请求微信登录
        String r = weChatService.code2Session(custom.getCredentials());
        if(ObjectUtils.isNotNull(r)) {
            AccountInfoBO bo = accountService.findAccountByPrincipal(TYPE, r);
            if(bo == null) {
                // 注册
                bo = accountService.createAccount(null,TYPE, r, custom.getCredentials());
            }
            custom.setAccountAuthTypeEnum(support());
            custom.setAccountInfoId(bo.getAccountInfoBean().getId());
            custom.setUsed(true);
            return custom;
        } else {
            return null;
        }
    }

    @Override
    public AccountConst.AccountAuthTypeEnum support() {
        return TYPE;
    }
}
