package com.qima.gift.appcommon.wechat.bean;

import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.qima.gift.common.CommonConst;
import lombok.Data;
import org.apache.commons.lang3.StringUtils;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/4 17:22
 */
public class Code2Session extends AbsWeChatBean<Code2Session.ReqParam, Code2Session.ResParam> implements IWeChatNeedAppId{

    public Code2Session() {
        super("code2Session", "https://api.weixin.qq.com/sns/jscode2session?appid={appid}&secret={secret}&js_code={js_code}&grant_type={grant_type}", "GET", new Code2Session.ReqParam());
    }

    @Override
    public Class<Code2Session.ResParam> getResParamClass() {
        return Code2Session.ResParam.class;
    }

    @Override
    public boolean isReqOk() {
        return !StringUtils.isAnyBlank(request.getJs_code(),request.getGrant_type());
    }

    @Override
    public boolean isResOk() {
        return response != null && (response.errcode == null || Integer.valueOf(CommonConst.INT_0).equals(response.errcode));
    }

    @Override
    public void setAppId(String appid) {
        getReqParam().setAppid(appid);
    }

    @Override
    public void setAppSecret(String appsecret) {
        getReqParam().setSecret(appsecret);
    }

    @Data
    @JsonPropertyOrder({"appid", "secret", "js_code", "grant_type"})
    public static class ReqParam{
        private String appid;  // 小程序唯一凭证，即 AppID，可在「微信公众平台 - 设置 - 开发设置」页中获得。（需要已经成为开发者，且帐号没有异常状态）
        private String secret;  // 小程序唯一凭证密钥，即 AppSecret，获取方式同 appid
        private String js_code;  // 填写 client_credential
        private String grant_type = "authorization_code";// 授权类型，此处只需填写 authorization_code
    }

    @Data
    public static class ResParam{
        private Integer errcode;// 错误时：错误码
        private String errmsg;// 错误时：错误信息
        private String session_key;  // 正确时：会话密钥
        private String unionid;  // 正确时：用户在开放平台的唯一标识符，若当前小程序已绑定到微信开放平台帐号下会返回
        private String openid; // 用户唯一标识
    }
}
