package com.qima.gift.appcommon.wechat.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import cn.dev33.satoken.stp.StpUtil;
import com.qima.gift.appcommon.account.AccountConst;
import com.qima.gift.appcommon.account.service.IAccountService;
import com.qima.gift.appcommon.security.satoken.LoginDataDTO;
import com.qima.gift.appcommon.security.service.ISecurityService;
import com.qima.gift.appcommon.wechat.service.IWeChatService;
import com.qima.gift.common.Result;
import com.qima.gift.common.utils.JsonUtils;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/7 10:21
 */
@Tag(name = "微信模块")
@RestController
public class WeChatController {

    @Autowired
    private IAccountService accountService;

    @Autowired
    private IWeChatService weChatService;

    @Autowired
    private ISecurityService securityService;

    @Operation(summary = "获取用户手机号，需要先登录", description = "内容格式：{\"code\":\"5分钟有效的授权码\"}")
    @PostMapping("/userphone")
    @SaCheckLogin
    public Result<String> getPhone(@RequestBody String json) {
        LoginDataDTO dto = securityService.getLoginData();
        Map<String,String> m = JsonUtils.toObject(json,Map.class);
        String phone = weChatService.getPhoneNumber(m.get("code"));
        if(StringUtils.isNotBlank(phone)) {
            accountService.saveAccountAuth(dto.getAccountId(), AccountConst.AccountAuthTypeEnum.Phone, phone, phone);
            return Result.ok("获取手机号成功", phone);
        } else {
            return Result.fail("获取手机号失败");
        }
    }

}
