package com.qima.gift.mall.bean;

import com.google.common.collect.Lists;
import com.google.common.collect.Sets;
import com.qima.gift.common.utils.CollectionUtils;
import lombok.Data;
import org.apache.commons.lang3.ObjectUtils;

import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/9 17:16
 */
@Data
public class MallShowBO {
    private MallShow mallShow;
    private List<MallGoodsSku> mallGoodsSkus = Lists.newArrayList();
    private List<MallCategory> mallCategories = Lists.newArrayList();

    public MallShowBO(){}

    public MallShowBO(MallShow mallShow) {
        this.mallShow = mallShow;
    }

    /** 方法区 ***/
    public List<String> findCategoryIds() {
        return mallShow.getContent().getE().getCategories();
    }

    public List<String> findGoodsSkuIds() {
        List<String> r = Lists.newArrayList();
        for(MallShowGoods g:mallShow.getContent().getE().getGoods()) {
            r.add(g.getSkuId());
        }
        return r;
    }

    /**
     * 在本秀中通过skuId找它的分类
     * @param skuId
     * @return
     */
    public MallCategory findMallCategoryBySku(String skuId) {
        MallShowGoods sku = mallShow.getContent().getE().findMallGoodsSkuById(skuId);
        if(sku != null) {
            for(MallCategory c:mallCategories) {
                if(c.getId().equals(sku.getCategoryId())){
                    return c;
                }
            }
        }
        return null;
    }

    /**
     * 在本秀中通过分类ID找它的商品
     * @param categoryId
     * @return
     */
    public List<MallGoodsSku> findMallGoodsSkusByCategory(String categoryId) {
        List<MallGoodsSku> r = Lists.newArrayList();
        List<MallShowGoods> skus = mallShow.getContent().getE().findMallGoodsSkuByCategory(categoryId);
        if(CollectionUtils.isNotEmpty(skus)) {
            Set<String> skuIds = Sets.newHashSet(CollectionUtils.convert(skus, MallShowGoods::getSkuId));
            for(MallGoodsSku sku:mallGoodsSkus) {
                if(skuIds.contains(sku.getId())) {
                    r.add(sku);
                }
            }
        }
        return r;
    }
}
