package com.qima.gift.mall.bean;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.google.common.collect.Sets;
import com.qima.gift.common.CommonConst;
import com.qima.gift.common.utils.ObjectUtils;
import lombok.Data;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/10 19:40
 */
@Data
public class MallShowContent {

    private List<String> categories = Lists.newArrayList();

    private List<MallShowGoods> goods = Lists.newArrayList();

    /** 方法区 **/
    /**
     * 根据分类变化情况重新加载商品
     * 情况1-新增的分类：key有，value无，good没有能对应上的；
     * 情况2-修改的分类：key有，value有且不同于key，good有能够对应value的；
     * 情况3-无修改的分类：key有，value有且同于key，good有能够对应key和value的；
     * @param cs key-当前分类ID，value-老的分类ID。
     */
    public void resetCategories(Map<String, String> cs) {
        // 清理删除了的分类对应的goods
        categories.clear();
        List<MallShowGoods> newgoods = Lists.newArrayList();
        if(cs != null) {
            categories.addAll(cs.keySet());
            Map<String,String> cs1 = Maps.newLinkedHashMap();
            cs.forEach((key, value) -> {
                if (value != null) {
                    cs1.put(value,key);
                }
            });
            for(MallShowGoods good:goods) {
                // 处理了情况1
                if(cs1.containsKey(good.getCategoryId())) {
                    // 处理了情况2、3
                    good.setCategoryId(cs1.get(good.getCategoryId()));
                    newgoods.add(good);
                }
            }
        }
        goods.clear();
        goods.addAll(newgoods);
    }

    public boolean findCategoryExist(String cid){
        return categories.contains(cid);
    }

    public boolean findSkuExist(String sid){
        return ObjectUtils.isNotNull(findMallGoodsSkuById(sid));
    }

    public void delGoodsSku(String sid) {
        for(int i = (goods.size()- CommonConst.INT_1); i>=CommonConst.INT_0; i--) {
            if(goods.get(i).getSkuId().equals(sid)){
                goods.remove(i);
            }
        }
    }

    /**
     * 在本秀中通过商品ID找它的分类
     * @param skuId
     * @return
     */
    public MallShowGoods findMallGoodsSkuById(String skuId) {
        for(MallShowGoods g:goods) {
            if(g.getSkuId().equals(skuId)) {
                return g;
            }
        }
        return null;
    }

    /**
     * 在本秀中通过分类ID找它的商品
     * @param categoryId
     * @return
     */
    public List<MallShowGoods> findMallGoodsSkuByCategory(String categoryId) {
        List<MallShowGoods> r = Lists.newArrayList();
        for(MallShowGoods g:goods) {
            if(g.getCategoryId().equals(categoryId)) {
                r.add(g);
            }
        }
        return r;
    }

}
