package com.qima.gift.mall.service;

import com.github.pagehelper.PageInfo;
import com.qima.gift.appcommon.space.base.IFileSource;
import com.qima.gift.common.CommonConst;
import com.qima.gift.common.page.Page;
import com.qima.gift.mall.bean.*;
import org.springframework.core.io.InputStreamSource;

import java.util.List;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/7 20:50
 */
public interface IMallService {

    /**
     * 保存商户
     * @param company 商户名
     * @param name 姓名
     * @param phone 电话
     * @param accountId 账户
     * @return 商户
     */
    MallMerchantBO saveMerchant(String company,String name, String phone, String accountId);

    /**
     * 修改商户
     * @param merchantId
     * @param company
     * @param name
     * @param phone
     * @return
     */
    MallMerchantBO updateMerchant(String merchantId, String company,String name, String phone);

    /**
     * 修改商户状态
     * @param merchantId
     * @param state
     * @return
     */
    MallMerchantBO updateMerchantState(String merchantId, CommonConst.StateEnum state);

    /**
     * 查找
     * @param id
     * @return
     */
    MallMerchant findMerchantById(String id);

    /**
     * 查询平台是所有的商户
     * @param name
     * @param pageNum
     * @param pageSize
     * @return
     */
    PageInfo<MallMerchantBO> findMerchants(String name, Integer pageNum, Integer pageSize);

    /**
     * 根据账户ID获取商户成员
     * @param merchatId
     * @param accountId
     * @return
     */
    MallMerchantMember findMemberByAccountId(String merchatId,String accountId);

    List<MallMerchantMember> findMembersByAccountId(String accountId);

    MallMerchantMember findMemberById(String id);

    /**
     * 根据商家查看他的秀
     * @param merchantId 商户唯一码
     * @param query 查询条件
     * @param pageNum 页码
     * @param pageSize 页数据条数
     * @return 分页结果
     */
    PageInfo<MallShowBO> findShowsByMerchantId(String merchantId, MallShowQuery query, Integer pageNum, Integer pageSize) ;

    /**
     * 根据ID查询秀
     * @param showId 秀的ID
     * @return 对应秀
     */
    MallShowBO findShowById(String showId);

    /**
     * 拷贝一个秀
     * @param showId
     * @return
     */
    MallShowBO doCopyShow(String showId);

    /**
     * 创建一个show
     * @param name 秀名称
     * @param des 秀描述（分享语）
     * @return 秀
     */
    MallShowBO createShow(String merchantId, String ownerId, String name, String des);

    /**
     * 给秀添加主题图片
     * @param showId 秀ID
     * @param topicColor 主题色
     * @param topicImage 主题图片ID
     * @return 主题图片的ID
     */
    String doSetShowTopic(String showId, String topicColor, String topicImage, String name, String des);

    /**
     * 给秀设置联系人
     * @param showId
     * @param showContact
     * @param showPhone
     * @return
     */
    String doSetShowContact(String showId, String showContact, String showPhone);

    /**
     * 分类编辑：按照分类保存
     * @param showId 秀ID
     * @param categorys 秀所有的分类
     * @return 保存后的新秀
     */
    MallShowBO doSaveShowCategorys(String showId, List<MallCategory> categorys);

    /**
     * 秀商品添加：按照秀分类添加一个商品
     * @param showId
     * @param categoryId
     * @param sku
     * @return
     */
    MallGoodsSku doAddShowGoods(String showId, String categoryId, MallGoodsSku sku);

    /**
     * 秀商品保存：保存一个秀商品
     * @param showId
     * @param showGoodsId
     * @param sku
     * @return
     */
    MallGoodsSku doUpdateShowGoods(String showId, String showGoodsId, MallGoodsSku sku);

    /**
     * 秀商品删除：按照秀商品ID删除一个商品
     * @param showId
     * @param showGoodsId
     * @return
     */
    Boolean doDelShowGoods(String showId, String showGoodsId);

    /**
     * 秀商品查询
     * @param showId
     * @param showgoodsId
     * @return
     */
    MallGoodsSku findShowGoods(String showId, String showgoodsId);

    /**
     * 发布秀
     * @param showId
     * @return
     */
    Boolean doPublishShow(String showId);

    /**
     * 删除一个秀
     * @param showId
     * @return
     */
    Boolean deleteShow(String showId);

}
