package com.qima.gift.mall.utils;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.qima.gift.appcommon.system.utils.SystemUtils;
import com.qima.gift.appcommon.typehandler.JObject;
import com.qima.gift.common.CommonConst;
import com.qima.gift.common.utils.IDUtils;
import com.qima.gift.common.utils.JsonUtils;
import com.qima.gift.common.utils.ObjectUtils;
import com.qima.gift.mall.bean.*;
import org.apache.commons.lang3.StringUtils;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * Copyright: Copyright (C) 2023 KingTom, Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限公司<p>
 *
 * @author King
 * @since 2023/6/9 17:59
 */
public class MallUtils {

    private MallUtils(){}

    public static MallShowDTO convert(MallShowBO bo, MallMerchant merchant,MallMerchantMember owner) {
        if(ObjectUtils.isNotNull(bo)) {
            MallShowDTO r = new MallShowDTO();
            r.setDes(bo.getMallShow().getDes());
            r.setExt1(bo.getMallShow().getExt1());
            r.setName(bo.getMallShow().getName());
            r.setCreater(bo.getMallShow().getCreater());
            r.setMerchantId(bo.getMallShow().getMerchantId());
            if(ObjectUtils.isNotNull(merchant)) {
                r.setMerchantName(merchant.getName());
            }
            if(StringUtils.isNotBlank(bo.getMallShow().getExt2())) {
                Map<String,String> map = JsonUtils.toObject(bo.getMallShow().getExt2(),Map.class);
                r.setShowContact(map.get("showContact"));
                r.setShowPhone(map.get("showPhone"));
            } else if( owner != null) {
                r.setShowContact(r.getMerchantName() + " " + owner.getName());
                r.setShowPhone(owner.getPhone());
            }
            r.setTopicColor(bo.getMallShow().getTopicColor());
            r.setGmtPublish(bo.getMallShow().getGmtPublish());
            r.setGmtModified(bo.getMallShow().getGmtModified());
            r.setGmtCreate(bo.getMallShow().getGmtCreate());
            r.setId(bo.getMallShow().getId());
            r.setTopicImage(bo.getMallShow().getTopicImage());
            r.setState(bo.getMallShow().getState());
            r.setSysId(bo.getMallShow().getSysId());
            if(bo.getMallCategories() != null) {
                for(MallCategory c:bo.getMallCategories()) {
                    r.getCategory().add(convert(c));
                }
            }
            if(bo.getMallGoodsSkus() != null) {
                for(MallGoodsSku s:bo.getMallGoodsSkus()) {
                    MallCategory c = bo.findMallCategoryBySku(s.getId());
                    r.getGoods().add(convert(s,c));
                }
            }
            return r;
        }
        return null;
    }

    public static MallShowBO convert(MallShowDTO bo) {
        // TODO 代码不完善
        if(ObjectUtils.isNotNull(bo)) {
            MallShow r = new MallShow();
            MallShowBO bor = new MallShowBO(r);
            r.setDes(bo.getDes());
            r.setExt1(bo.getExt1());
            r.setName(bo.getName());
            r.setCreater(bo.getCreater());
            Map<String,String> map = Maps.newHashMap();
            map.put("showContact", bo.getShowContact());
            map.put("showPhone", bo.getShowPhone());
            r.setExt2(JsonUtils.toJson(map));
            r.setMerchantId(bo.getMerchantId());
            r.setTopicColor(bo.getTopicColor());
            r.setGmtPublish(bo.getGmtPublish());
            r.setGmtModified(bo.getGmtModified());
            r.setGmtCreate(bo.getGmtCreate());
            r.setId(bo.getId());
            r.setTopicImage(bo.getTopicImage());
            r.setState(bo.getState());
            r.setSysId(bo.getSysId());
            if(bo.getGoods() != null) {
                for(MallShowGoodsDTO c:bo.getGoods()) {
                    bor.getMallGoodsSkus().add(convert(c));
                }
            }
            if(bo.getCategory() != null) {
                for(MallCategoryDTO s:bo.getCategory()) {
                    bor.getMallCategories().add(convert(s));
                }
            }
            return bor;
        }
        return null;
    }

    public static MallShowGoodsDTO convert(MallGoodsSku bo,MallCategory c) {
        if(ObjectUtils.isNotNull(bo)) {
            MallShowGoodsDTO r = new MallShowGoodsDTO();
            r.setId(bo.getId());
            r.setName(bo.getName());
            r.setPrice(bo.getPrice());
            r.setGoodsId(bo.getGoodsId());
            r.setTopicImage(bo.getTopicImage());
            r.setDes(bo.getDes());
            List<String> images = Lists.newArrayList(StringUtils.split(bo.getDesImages(), CommonConst.COMMA_STRING));
            r.setDesImages(images);
            if(ObjectUtils.isNotNull(c)) {
                r.setCategoryId(c.getId());
                r.setCategoryName(c.getName());
            }
            r.setGmtCreate(bo.getGmtCreate());
            r.setGmtModified(bo.getGmtModified());
            r.setSysId(bo.getSysId());
            return r;
        }
        return null;
    }

    public static MallGoodsSku convert(MallShowGoodsDTO bo) {
        if(ObjectUtils.isNotNull(bo)) {
            MallGoodsSku r = new MallGoodsSku();
            r.setId(bo.getId());
            r.setPrice(bo.getPrice());
            r.setGoodsId(bo.getGoodsId());
            r.setName(bo.getName());
            r.setTopicImage(bo.getTopicImage());
            r.setDes(bo.getDes());
            r.setDesImages(bo.getDesImages()==null?"":StringUtils.join(bo.getDesImages(),CommonConst.COMMA_STRING));
            r.setGmtCreate(bo.getGmtCreate());
            r.setGmtModified(bo.getGmtModified());
            r.setSysId(bo.getSysId());
            return r;
        }
        return null;
    }

    public static MallCategoryDTO convert(MallCategory bo) {
        if(ObjectUtils.isNotNull(bo)) {
            MallCategoryDTO r = new MallCategoryDTO();
            r.setId(bo.getId());
            r.setName(bo.getName());
            return r;
        }
        return null;
    }

    public static MallCategory convert(MallCategoryDTO dto) {
        if(ObjectUtils.isNotNull(dto)) {
            MallCategory r = new MallCategory();
            r.setId(dto.getId());
            r.setName(dto.getName());
            return r;
        }
        return null;
    }

    public static MallMerchantDTO convert(MallMerchantBO bo) {
        if(ObjectUtils.isNotNull(bo)) {
            MallMerchantDTO r = new MallMerchantDTO();
            r.setId(bo.getMallMerchant().getId());
            r.setName(bo.getMallMerchant().getName());
            r.setGmtModified(bo.getMallMerchant().getGmtModified());
            r.setGmtCreate(bo.getMallMerchant().getGmtCreate());
            r.setOwner(bo.getMallMerchant().getOwner());
            MallMerchantMember member = bo.findOwner();
            if(member != null) {
                r.setOwnerName(member.getName());
                r.setOwnerPhone(member.getPhone());
            }
            r.setState(bo.getMallMerchant().getState());
            if(bo.getMallMerchantMembers() != null) {
                for(MallMerchantMember merchantMember:bo.getMallMerchantMembers()) {
                    MallMerchantMemberDTO mdto = new MallMerchantMemberDTO();
                    mdto.setId(merchantMember.getId());
                    mdto.setState(merchantMember.getState());
                    mdto.setName(merchantMember.getName());
                    mdto.setGmtModified(merchantMember.getGmtModified());
                    mdto.setGmtCreate(merchantMember.getGmtCreate());
                    r.getMembers().add(mdto);
                }
            }
            return r;
        }
        return null;
    }

    public static <T> void fillBeanBeforeInsert(T b) {
        if(b != null) {
            Date now = new Date();
            if(b instanceof MallShow bean) {
                bean.setId(IDUtils.newUUID());
                bean.setState(CommonConst.StateEnum.Unkown.getKey());// 默认草稿
                bean.setGmtCreate(now);
                bean.setGmtModified(now);
                bean.setSysId(SystemUtils.getCurrentSystemId());
                if(bean.getContent() == null) {
                    bean.setContent(new JObject<>(new MallShowContent()));
                }
            } else if(b instanceof MallGoods bean) {
                bean.setId(IDUtils.newUUID());
                bean.setGmtCreate(now);
                bean.setGmtModified(now);
                bean.setState(CommonConst.StateEnum.Enable.getKey());// 默认启用
                bean.setSysId(SystemUtils.getCurrentSystemId());
            } else if(b instanceof MallGoodsSku bean) {
                bean.setId(IDUtils.newUUID());
                bean.setGmtCreate(now);
                bean.setGmtModified(now);
                bean.setState(CommonConst.StateEnum.Enable.getKey());// 默认上架
                bean.setSysId(SystemUtils.getCurrentSystemId());
            } else if(b instanceof MallCategory bean) {
                bean.setId(IDUtils.newUUID());
                bean.setGmtCreate(now);
                bean.setGmtModified(now);
                bean.setState(CommonConst.StateEnum.Enable.getKey());// 默认启用
                bean.setSysId(SystemUtils.getCurrentSystemId());
            } else if(b instanceof MallMerchant bean) {
                bean.setId(IDUtils.newUUID());
                bean.setGmtCreate(now);
                bean.setGmtModified(now);
                bean.setState(CommonConst.StateEnum.Enable.getKey());// 默认启用
                bean.setSysId(SystemUtils.getCurrentSystemId());
            } else if(b instanceof MallMerchantMember bean) {
                bean.setId(IDUtils.newUUID());
                bean.setGmtCreate(now);
                bean.setGmtModified(now);
                bean.setState(CommonConst.StateEnum.Enable.getKey());// 默认启用
                bean.setSysId(SystemUtils.getCurrentSystemId());
            }
        }
    }

    public static <T> void fillBeanBeforeUpdate(T dbB,T customB) {
        if(customB != null && dbB != null) {
            Date now = new Date();
            if(customB instanceof MallShow bean && dbB instanceof MallShow dbBean) {
                bean.setId(dbBean.getId());
                bean.setMerchantId(dbBean.getMerchantId());
                bean.setGmtCreate(dbBean.getGmtCreate());
                bean.setGmtModified(now);
                bean.setSysId(dbBean.getSysId());
                if(bean.getContent() == null) {
                    bean.setContent(new JObject<>(new MallShowContent()));
                }
            } else if(customB instanceof MallGoods bean && dbB instanceof MallGoods dbBean) {
                bean.setId(dbBean.getId());
                bean.setMerchantId(dbBean.getMerchantId());
                bean.setGmtCreate(dbBean.getGmtCreate());
                bean.setGmtModified(now);
                bean.setSysId(dbBean.getSysId());
            } else if(customB instanceof MallGoodsSku bean && dbB instanceof MallGoodsSku dbBean) {
                bean.setId(dbBean.getId());
                bean.setMerchantId(dbBean.getMerchantId());
                bean.setGoodsId(dbBean.getMerchantId());
                bean.setGmtCreate(dbBean.getGmtCreate());
                bean.setState(dbBean.getState());
                bean.setGmtModified(now);
                bean.setSysId(dbBean.getSysId());
            } else if(customB instanceof MallCategory bean && dbB instanceof MallCategory dbBean) {
                bean.setId(IDUtils.newUUID());
                bean.setGmtCreate(dbBean.getGmtCreate());
                bean.setGmtModified(now);
                bean.setSysId(dbBean.getSysId());
            } else if(customB instanceof MallMerchant bean && dbB instanceof MallMerchant dbBean) {
                bean.setId(IDUtils.newUUID());
                bean.setOwner(dbBean.getOwner());
                bean.setGmtCreate(dbBean.getGmtCreate());
                bean.setGmtModified(now);
                bean.setSysId(dbBean.getSysId());
            } else if(customB instanceof MallMerchantMember bean && dbB instanceof MallMerchantMember dbBean) {
                bean.setId(IDUtils.newUUID());
                bean.setAccountId(dbBean.getAccountId());
                bean.setMerchantId(dbBean.getMerchantId());
                bean.setGmtCreate(dbBean.getGmtCreate());
                bean.setGmtModified(now);
                bean.setSysId(dbBean.getSysId());
            }
        } else if (customB != null) {
            Date now = new Date();
            if(customB instanceof MallShow bean) {
                bean.setGmtModified(now);
                if(bean.getContent() == null) {
                    bean.setContent(new JObject<>(new MallShowContent()));
                }
            } else if(customB instanceof MallGoods bean) {
                bean.setGmtModified(now);
            } else if(customB instanceof MallGoodsSku bean) {
                bean.setGmtModified(now);
            } else if(customB instanceof MallCategory bean) {
                bean.setGmtModified(now);
            } else if(customB instanceof MallMerchant bean) {
                bean.setGmtModified(now);
            } else if(customB instanceof MallMerchantMember bean) {
                bean.setGmtModified(now);
            }
        }
    }

}
