-- ----------------------------
-- Table structure for mall_merchant
-- ----------------------------
DROP TABLE IF EXISTS "public"."mall_merchant";
CREATE TABLE "public"."mall_merchant" (
    "id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "name" varchar(256) COLLATE "pg_catalog"."default",
    "owner" varchar(36) COLLATE "pg_catalog"."default",
    "state" int4 NOT NULL,
    "ext1" varchar(1024) COLLATE "pg_catalog"."default",
    "ext2" varchar(1024) COLLATE "pg_catalog"."default",
    "gmt_create" timestamp(3) NOT NULL,
    "gmt_modified" timestamp(3) NOT NULL,
    "sys_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL
)
;
COMMENT ON COLUMN "public"."mall_merchant"."id" IS '主键';
COMMENT ON COLUMN "public"."mall_merchant"."name" IS '商家名称';
COMMENT ON COLUMN "public"."mall_merchant"."owner" IS '商家主体归属';
COMMENT ON COLUMN "public"."mall_merchant"."state" IS '状态:1正常,0停用,-1审核,-2异常';
COMMENT ON COLUMN "public"."mall_merchant"."ext1" IS '扩展字段1';
COMMENT ON COLUMN "public"."mall_merchant"."ext2" IS '扩展字段2';
COMMENT ON COLUMN "public"."mall_merchant"."gmt_create" IS '创建时间';
COMMENT ON COLUMN "public"."mall_merchant"."gmt_modified" IS '更新时间';
COMMENT ON COLUMN "public"."mall_merchant"."sys_id" IS '系统ID';
COMMENT ON TABLE "public"."mall_merchant" IS '商城商家';

-- ----------------------------
-- Primary Key structure for table mall_merchant
-- ----------------------------
ALTER TABLE "public"."mall_merchant" ADD CONSTRAINT "mall_merchant_pkey" PRIMARY KEY ("id");

-- ----------------------------
-- Table structure for mall_merchant_member
-- ----------------------------
DROP TABLE IF EXISTS "public"."mall_merchant_member";
CREATE TABLE "public"."mall_merchant_member" (
    "id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "name" varchar(256) COLLATE "pg_catalog"."default" NOT NULL,
    "phone" varchar(256) COLLATE "pg_catalog"."default",
    "merchant_id" varchar(36) COLLATE "pg_catalog"."default",
    "account_id" varchar(36) COLLATE "pg_catalog"."default",
    "state" int4 NOT NULL,
    "ext1" varchar(1024) COLLATE "pg_catalog"."default",
    "ext2" varchar(1024) COLLATE "pg_catalog"."default",
    "gmt_create" timestamp(3) NOT NULL,
    "gmt_modified" timestamp(3) NOT NULL,
    "sys_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL
)
;
COMMENT ON COLUMN "public"."mall_merchant_member"."id" IS '主键';
COMMENT ON COLUMN "public"."mall_merchant_member"."name" IS '员工姓名';
COMMENT ON COLUMN "public"."mall_merchant_member"."phone" IS '员工电话';
COMMENT ON COLUMN "public"."mall_merchant_member"."merchant_id" IS '商户ID';
COMMENT ON COLUMN "public"."mall_merchant_member"."account_id" IS '账户ID';
COMMENT ON COLUMN "public"."mall_merchant_member"."state" IS '账户状态:0正常,1-未登录,2-停用';
COMMENT ON COLUMN "public"."mall_merchant_member"."ext1" IS '扩展字段1';
COMMENT ON COLUMN "public"."mall_merchant_member"."ext2" IS '扩展字段2';
COMMENT ON COLUMN "public"."mall_merchant_member"."gmt_create" IS '创建时间';
COMMENT ON COLUMN "public"."mall_merchant_member"."gmt_modified" IS '更新时间';
COMMENT ON COLUMN "public"."mall_merchant_member"."sys_id" IS '系统ID';
COMMENT ON TABLE "public"."mall_merchant_member" IS '商户员工表';

-- ----------------------------
-- Primary Key structure for table mall_merchant_member
-- ----------------------------
ALTER TABLE "public"."mall_merchant_member" ADD CONSTRAINT "mall_merchant_member_pkey" PRIMARY KEY ("id");

-- ----------------------------
-- Table structure for mall_show
-- ----------------------------
DROP TABLE IF EXISTS "public"."mall_show";
CREATE TABLE "public"."mall_show" (
    "id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "name" varchar(256) COLLATE "pg_catalog"."default" NOT NULL,
    "topic_image" varchar(36) COLLATE "pg_catalog"."default",
    "topic_color" varchar(256) COLLATE "pg_catalog"."default",
    "des" varchar(1024) COLLATE "pg_catalog"."default",
    "merchant_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "creater" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "content" jsonb,
    "gmt_publish" timestamp(3),
    "state" int4 NOT NULL,
    "ext1" varchar(1024) COLLATE "pg_catalog"."default",
    "ext2" varchar(1024) COLLATE "pg_catalog"."default",
    "gmt_create" timestamp(3) NOT NULL,
    "gmt_modified" timestamp(3) NOT NULL,
    "sys_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL
)
;
COMMENT ON COLUMN "public"."mall_show"."id" IS '主键';
COMMENT ON COLUMN "public"."mall_show"."name" IS '主题名称';
COMMENT ON COLUMN "public"."mall_show"."topic_image" IS '主题图片';
COMMENT ON COLUMN "public"."mall_show"."topic_color" IS '主题色';
COMMENT ON COLUMN "public"."mall_show"."des" IS '秀描述';
COMMENT ON COLUMN "public"."mall_show"."merchant_id" IS '所属商家';
COMMENT ON COLUMN "public"."mall_show"."creater" IS '创建者';
COMMENT ON COLUMN "public"."mall_show"."content" IS '分类、商品';
COMMENT ON COLUMN "public"."mall_show"."gmt_publish" IS '发布时间';
COMMENT ON COLUMN "public"."mall_show"."state" IS '状态:1正常,0停用,-1草稿,-2删除';
COMMENT ON COLUMN "public"."mall_show"."ext1" IS '扩展字段1';
COMMENT ON COLUMN "public"."mall_show"."ext2" IS '扩展字段2';
COMMENT ON COLUMN "public"."mall_show"."gmt_create" IS '创建时间';
COMMENT ON COLUMN "public"."mall_show"."gmt_modified" IS '更新时间';
COMMENT ON COLUMN "public"."mall_show"."sys_id" IS '系统ID';
COMMENT ON TABLE "public"."mall_show" IS '商城礼品秀';

-- ----------------------------
-- Primary Key structure for table mall_show
-- ----------------------------
ALTER TABLE "public"."mall_show" ADD CONSTRAINT "mall_show_pkey" PRIMARY KEY ("id");

-- ----------------------------
-- Table structure for mall_category
-- ----------------------------
DROP TABLE IF EXISTS "public"."mall_category";
CREATE TABLE "public"."mall_category" (
    "id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "name" varchar(1024) COLLATE "pg_catalog"."default" NOT NULL,
    "merchant_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "state" int4 NOT NULL,
    "ext1" varchar(1024) COLLATE "pg_catalog"."default",
    "ext2" varchar(1024) COLLATE "pg_catalog"."default",
    "gmt_create" timestamp(3) NOT NULL,
    "gmt_modified" timestamp(3) NOT NULL,
    "sys_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL
)
;
COMMENT ON COLUMN "public"."mall_category"."id" IS '主键';
COMMENT ON COLUMN "public"."mall_category"."name" IS '商品分类名称';
COMMENT ON COLUMN "public"."mall_category"."merchant_id" IS '所属商家';
COMMENT ON COLUMN "public"."mall_category"."state" IS '状态:1启用,0停用,-1未知,-2异常';
COMMENT ON COLUMN "public"."mall_category"."ext1" IS '扩展字段1';
COMMENT ON COLUMN "public"."mall_category"."ext2" IS '扩展字段2';
COMMENT ON COLUMN "public"."mall_category"."gmt_create" IS '创建时间';
COMMENT ON COLUMN "public"."mall_category"."gmt_modified" IS '更新时间';
COMMENT ON COLUMN "public"."mall_category"."sys_id" IS '系统ID';
COMMENT ON TABLE "public"."mall_category" IS '商城商品分类';

-- ----------------------------
-- Primary Key structure for table mall_category
-- ----------------------------
ALTER TABLE "public"."mall_category" ADD CONSTRAINT "mall_category_pkey" PRIMARY KEY ("id");

-- ----------------------------
-- Table structure for mall_goods
-- ----------------------------
DROP TABLE IF EXISTS "public"."mall_goods";
CREATE TABLE "public"."mall_goods" (
    "id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "name" varchar(1024) COLLATE "pg_catalog"."default" NOT NULL,
    "merchant_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "default_sku" varchar(36) COLLATE "pg_catalog"."default",
    "state" int4 NOT NULL,
    "ext1" varchar(1024) COLLATE "pg_catalog"."default",
    "ext2" varchar(1024) COLLATE "pg_catalog"."default",
    "gmt_create" timestamp(3) NOT NULL,
    "gmt_modified" timestamp(3) NOT NULL,
    "sys_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL
)
;
COMMENT ON COLUMN "public"."mall_goods"."id" IS '主键';
COMMENT ON COLUMN "public"."mall_goods"."name" IS '商品名称';
COMMENT ON COLUMN "public"."mall_goods"."merchant_id" IS '所属商家';
COMMENT ON COLUMN "public"."mall_goods"."default_sku" IS '默认的sku';
COMMENT ON COLUMN "public"."mall_goods"."state" IS '状态:1启用,0停用,-1未知,-2异常';
COMMENT ON COLUMN "public"."mall_goods"."ext1" IS '扩展字段1';
COMMENT ON COLUMN "public"."mall_goods"."ext2" IS '扩展字段2';
COMMENT ON COLUMN "public"."mall_goods"."gmt_create" IS '创建时间';
COMMENT ON COLUMN "public"."mall_goods"."gmt_modified" IS '更新时间';
COMMENT ON COLUMN "public"."mall_goods"."sys_id" IS '系统ID';
COMMENT ON TABLE "public"."mall_goods" IS '商城商品';

-- ----------------------------
-- Primary Key structure for table mall_goods
-- ----------------------------
ALTER TABLE "public"."mall_goods" ADD CONSTRAINT "mall_goods_pkey" PRIMARY KEY ("id");

-- ----------------------------
-- Table structure for mall_goods_sku
-- ----------------------------
DROP TABLE IF EXISTS "public"."mall_goods_sku";
CREATE TABLE "public"."mall_goods_sku" (
    "id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "name" varchar(1024) COLLATE "pg_catalog"."default" NOT NULL,
    "goods_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "merchant_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL,
    "topic_image" varchar(36) COLLATE "pg_catalog"."default",
    "des_images" varchar(1024) COLLATE "pg_catalog"."default",
    "price" varchar(1024) COLLATE "pg_catalog"."default",
    "des" varchar(1024) COLLATE "pg_catalog"."default",
    "state" int4 NOT NULL,
    "ext1" varchar(1024) COLLATE "pg_catalog"."default",
    "ext2" varchar(1024) COLLATE "pg_catalog"."default",
    "gmt_create" timestamp(3) NOT NULL,
    "gmt_modified" timestamp(3) NOT NULL,
    "sys_id" varchar(36) COLLATE "pg_catalog"."default" NOT NULL
)
;
COMMENT ON COLUMN "public"."mall_goods_sku"."id" IS '主键';
COMMENT ON COLUMN "public"."mall_goods_sku"."name" IS 'SKU名称';
COMMENT ON COLUMN "public"."mall_goods_sku"."merchant_id" IS '所属商家';
COMMENT ON COLUMN "public"."mall_goods_sku"."goods_id" IS '所属商品';
COMMENT ON COLUMN "public"."mall_goods_sku"."topic_image" IS '主题图片';
COMMENT ON COLUMN "public"."mall_goods_sku"."des_images" IS '描述图片集';
COMMENT ON COLUMN "public"."mall_goods_sku"."price" IS '价格';
COMMENT ON COLUMN "public"."mall_goods_sku"."des" IS '分享描述';
COMMENT ON COLUMN "public"."mall_goods_sku"."state" IS '状态:1商家,0下架,-1未知,-2异常';
COMMENT ON COLUMN "public"."mall_goods_sku"."ext1" IS '扩展字段1';
COMMENT ON COLUMN "public"."mall_goods_sku"."ext2" IS '扩展字段2';
COMMENT ON COLUMN "public"."mall_goods_sku"."gmt_create" IS '创建时间';
COMMENT ON COLUMN "public"."mall_goods_sku"."gmt_modified" IS '更新时间';
COMMENT ON COLUMN "public"."mall_goods_sku"."sys_id" IS '系统ID';
COMMENT ON TABLE "public"."mall_goods_sku" IS '商城商品';

-- ----------------------------
-- Primary Key structure for table mall_goods_sku
-- ----------------------------
ALTER TABLE "public"."mall_goods_sku" ADD CONSTRAINT "mall_goods_sku_pkey" PRIMARY KEY ("id");